@@ -504,7 +504,7 @@ class Statbotics:
         if week is not None:
             url += "&week=" + str(week)
         if elims is not None:
-            url += "&playoff=" + str(elims)
+            url += "&elims=" + str(elims)
 
         if metric not in match_metrics:
             raise ValueError("Invalid metric")
@@ -536,8 +536,8 @@ class Statbotics:
         team: Optional[int] = None,
         year: Optional[int] = None,
         event: Optional[str] = None,
-        week: Optional[int] = None,
         match: Optional[str] = None,
+        week: Optional[int] = None,
         elims: Optional[bool] = None,
         metric: str = "time",
         ascending: Optional[bool] = None,
@@ -601,7 +601,7 @@ class Statbotics:
         if match is not None:
             url += "&match=" + match
         if elims is not None:
-            url += "&playoff=" + str(elims)
+            url += "&elims=" + str(elims)
 
         if metric not in team_match_metrics:
             raise ValueError("Invalid metric")
